@@ -2,6 +2,7 @@ import cv2
 import os
 import numpy as np
 from cv2 import aruco
+import json
 
 def calibrate_camera(image_paths, board, req_markers=10):
     all_corners = []
@@ -118,9 +119,18 @@ def fit_plane_svd(points):
     U, S, Vt = np.linalg.svd(points - mean)
     normal = Vt[-1]
     d = -normal.dot(mean)
+    if d < 0:
+        normal = -normal
+        d = -d
     return np.concatenate((normal, [d]))
 
-def load_board_from_dict(board_dict):
+
+def read_json(path):
+    with open(path, 'r') as f:
+        return json.load(f)
+
+def load_charuco_board(json_path):
+    board_dict = read_json(json_path)
     squares_x = board_dict['square_x']
     squares_y = board_dict['square_y']
     cb_sq_width = board_dict['cb_sq_width']
@@ -128,3 +138,4 @@ def load_board_from_dict(board_dict):
     aruco_dict_str = board_dict['aruco_dict_str']
     start_id = board_dict['start_id']
     return create_board(squares_x, squares_y, cb_sq_width, aruco_sq_width, aruco_dict_str, start_id)
+
